[gtk] gtk: Fix some g-i annotations warnings



commit f3e6d00db17cf22d8e9b875452dc7a7ed72bd677
Author: Rico Tzschichholz <ricotz ubuntu com>
Date:   Mon Sep 17 13:00:36 2018 +0200

    gtk: Fix some g-i annotations warnings

 gtk/gtkfilterlistmodel.c |  4 ++--
 gtk/gtkfilterlistmodel.h |  2 +-
 gtk/gtkmaplistmodel.c    | 10 +++++-----
 gtk/gtkmaplistmodel.h    |  4 ++--
 gtk/gtkslicelistmodel.c  |  2 +-
 gtk/gtksortlistmodel.c   |  2 +-
 gtk/gtktreelistmodel.h   | 10 +++++-----
 7 files changed, 17 insertions(+), 17 deletions(-)
---
diff --git a/gtk/gtkfilterlistmodel.c b/gtk/gtkfilterlistmodel.c
index 47def9656d..bf2ced74e5 100644
--- a/gtk/gtkfilterlistmodel.c
+++ b/gtk/gtkfilterlistmodel.c
@@ -459,7 +459,7 @@ gtk_filter_list_model_augment (GtkCssRbTree *filter,
  * @model: the model to sort
  * @filter_func: (allow-none): filter function or %NULL to not filter items
  * @user_data: user data passed to @filter_func
- * @destroy: destroy notifier for @user_data
+ * @user_destroy: destroy notifier for @user_data
  *
  * Creates a new #GtkFilterListModel that will filter @model using the given
  * @filter_func.
@@ -512,7 +512,7 @@ gtk_filter_list_model_new_for_type (GType item_type)
  * @self: a #GtkFilterListModel
  * @filter_func: (allow-none): filter function or %NULL to not filter items
  * @user_data: user data passed to @filter_func
- * @destroy: destroy notifier for @user_data
+ * @user_destroy: destroy notifier for @user_data
  *
  * Sets the function used to filter items. The function will be called for every
  * item and if it returns %TRUE the item is considered visible.
diff --git a/gtk/gtkfilterlistmodel.h b/gtk/gtkfilterlistmodel.h
index f19607fd70..3ab1601ff5 100644
--- a/gtk/gtkfilterlistmodel.h
+++ b/gtk/gtkfilterlistmodel.h
@@ -36,7 +36,7 @@ G_BEGIN_DECLS
 GDK_AVAILABLE_IN_ALL
 G_DECLARE_FINAL_TYPE (GtkFilterListModel, gtk_filter_list_model, GTK, FILTER_LIST_MODEL, GObject)
 
-typedef gboolean (* GtkFilterListModelFilterFunc) (gpointer item, gpointer data);
+typedef gboolean (* GtkFilterListModelFilterFunc) (gpointer item, gpointer user_data);
 
 GDK_AVAILABLE_IN_ALL
 GtkFilterListModel *    gtk_filter_list_model_new               (GListModel             *model,
diff --git a/gtk/gtkmaplistmodel.h b/gtk/gtkmaplistmodel.h
index 185c8ed0da..e5c637297a 100644
--- a/gtk/gtkmaplistmodel.h
+++ b/gtk/gtkmaplistmodel.h
@@ -39,13 +39,13 @@ G_DECLARE_FINAL_TYPE (GtkMapListModel, gtk_map_list_model, GTK, MAP_LIST_MODEL,
 /**
  * GtkMapListModelMapFunc:
  * @item: (transfer full): The item to map
- * @data: user data
+ * @user_data: user data
  *
  * User function that is called to map an @item of the original model.
  *
  * Returns: (transfer full): The item to map to. This function may not return %NULL
  */
-typedef gpointer (* GtkMapListModelMapFunc) (gpointer item, gpointer data);
+typedef gpointer (* GtkMapListModelMapFunc) (gpointer item, gpointer user_data);
 
 GDK_AVAILABLE_IN_ALL
 GtkMapListModel *       gtk_map_list_model_new                  (GType                   item_type,
diff --git a/gtk/gtkslicelistmodel.c b/gtk/gtkslicelistmodel.c
index 95c6eaa03d..2345b2e716 100644
--- a/gtk/gtkslicelistmodel.c
+++ b/gtk/gtkslicelistmodel.c
@@ -470,7 +470,7 @@ gtk_slice_list_model_get_offset (GtkSliceListModel *self)
 }
 
 /**
- * gtk_slice_list_model_set_offset:
+ * gtk_slice_list_model_set_size:
  * @self: a #GtkSliceListModel
  * @size: the maximum size
  *
diff --git a/gtk/gtksortlistmodel.c b/gtk/gtksortlistmodel.c
index f127791ebc..4b9fa64acf 100644
--- a/gtk/gtksortlistmodel.c
+++ b/gtk/gtksortlistmodel.c
@@ -418,7 +418,7 @@ gtk_sort_list_model_create_sequences (GtkSortListModel *self)
  * @self: a #GtkSortListModel
  * @sort_func: (allow-none): sort function or %NULL to not sort items
  * @user_data: user data passed to @sort_func
- * @destroy: destroy notifier for @user_data
+ * @user_destroy: destroy notifier for @user_data
  *
  * Sets the function used to sort items. The function will be called for every
  * item and must return an integer less than, equal to, or greater than zero if
diff --git a/gtk/gtkmaplistmodel.c b/gtk/gtkmaplistmodel.c
index 028bc060e4..6a3de78f8b 100644
--- a/gtk/gtkmaplistmodel.c
+++ b/gtk/gtkmaplistmodel.c
@@ -421,7 +421,7 @@ gtk_map_list_model_augment (GtkCssRbTree *map,
  * @model: (allow-none): The model to map or %NULL for none
  * @map_func: (allow-none): map function or %NULL to not map items
  * @user_data: user data passed to @map_func
  * @destroy: destroy notifier for @user_data
  *
  * Creates a new #GtkMapListModel for the given arguments.
  *
@@ -431,8 +431,8 @@ GtkMapListModel *
 gtk_map_list_model_new (GType                   item_type,
                         GListModel             *model,
                         GtkMapListModelMapFunc  map_func,
-                        gpointer                data,
-                        GDestroyNotify          data_destroy)
+                        gpointer                user_data,
+                        GDestroyNotify          user_destroy)
 {
   GtkMapListModel *result;
 
@@ -445,7 +445,7 @@ gtk_map_list_model_new (GType                   item_type,
                          NULL);
 
   if (map_func)
-    gtk_map_list_model_set_map_func (result, map_func, data, data_destroy);
+    gtk_map_list_model_set_map_func (result, map_func, user_data, user_destroy);
 
   return result;
 }
@@ -498,7 +498,7 @@ gtk_map_list_model_init_items (GtkMapListModel *self)
  * @self: a #GtkMapListModel
  * @map_func: (allow-none): map function or %NULL to not map items
  * @user_data: user data passed to @map_func
  * @destroy: destroy notifier for @user_data
  *
  * Sets the function used to map items. The function will be called whenever
  * an item needs to be mapped and must return the item to use for the given
@@ -421,7 +421,7 @@ gtk_map_list_model_augment (GtkCssRbTree *map,
  * @map_func: (allow-none): map function or %NULL to not map items
  * @user_data: user data passed to @map_func
- * @destroy: destroy notifier for @user_data
+ * @user_destroy: destroy notifier for @user_data
  *
  * Creates a new #GtkMapListModel for the given arguments.
@@ -498,7 +498,7 @@ gtk_map_list_model_init_items (GtkMapListModel *self)
  * @map_func: (allow-none): map function or %NULL to not map items
  * @user_data: user data passed to @map_func
- * @destroy: destroy notifier for @user_data
+ * @user_destroy: destroy notifier for @user_data
  *
  * Sets the function used to map items. The function will be called whenever
diff --git a/gtk/gtktreelistmodel.h b/gtk/gtktreelistmodel.h
index 9b34735acd..fd9585e2be 100644
--- a/gtk/gtktreelistmodel.h
+++ b/gtk/gtktreelistmodel.h
@@ -42,20 +42,20 @@ G_DECLARE_FINAL_TYPE (GtkTreeListRow, gtk_tree_list_row, GTK, TREE_LIST_ROW, GOb
 /**
  * GtkTreeListModelCreateModelFunc:
  * @item: The item that is expaned
  * @data: User data passed when registering the function
  *
  * Prototype of the function called to create new child models when
  * gtk_tree_list_row_set_expanded() is called.
  */
-typedef GListModel * (* GtkTreeListModelCreateModelFunc) (gpointer item, gpointer data);
+typedef GListModel * (* GtkTreeListModelCreateModelFunc) (gpointer item, gpointer user_data);
 
 GDK_AVAILABLE_IN_ALL
 GtkTreeListModel *      gtk_tree_list_model_new                 (gboolean                passthrough,
                                                                  GListModel             *root,
                                                                  gboolean                autoexpand,
                                                                  GtkTreeListModelCreateModelFunc create_func,
-                                                                 gpointer                data,
-                                                                 GDestroyNotify          data_destroy);
+                                                                 gpointer                user_data,
+                                                                 GDestroyNotify          user_destroy);
 
 GDK_AVAILABLE_IN_ALL
 GListModel *            gtk_tree_list_model_get_model           (GtkTreeListModel       *self);
@@ -93,7 +93,7 @@ GDK_AVAILABLE_IN_ALL
 GtkTreeListRow *        gtk_tree_list_row_get_parent            (GtkTreeListRow         *self);
 GDK_AVAILABLE_IN_ALL
 GtkTreeListRow *        gtk_tree_list_row_get_child             (GtkTreeListRow         *self,
-                                                                 guint                   child);
+                                                                 guint                   position);
 
 
 G_END_DECLS
@@ -42,20 +42,20 @@ G_DECLARE_FINAL_TYPE (GtkTreeListRow, gtk_tree_list_row, GTK, TREE_LIST_ROW, GOb
  * GtkTreeListModelCreateModelFunc:
  * @item: The item that is expaned
- * @data: User data passed when registering the function
+ * @user_data: User data passed when registering the function
  *
  * Prototype of the function called to create new child models when


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]